@@ -14,7 +14,6 @@
 
 import collections
 import ipaddress
-import pyroute2
 import threading
 
 from oslo_concurrency import lockutils
@@ -30,6 +29,7 @@ from ovn_bgp_agent.drivers.openstack.utils import ovs
 from ovn_bgp_agent.drivers.openstack.utils import wire as wire_utils
 from ovn_bgp_agent.drivers.openstack.watchers import bgp_watcher as watcher
 from ovn_bgp_agent import exceptions as agent_exc
+from ovn_bgp_agent.utils import helpers
 from ovn_bgp_agent.utils import linux_net
 
 
@@ -168,44 +168,47 @@ class OVNBGPDriver(driver_api.AgentDriverBase):
         bridge_mappings = self.ovs_idl.get_ovn_bridge_mappings()
         # 2) Get macs for bridge mappings
         extra_routes = {}
-        with pyroute2.NDB() as ndb:
-            for bridge_index, bridge_mapping in enumerate(bridge_mappings, 1):
-                network = bridge_mapping.split(":")[0]
-                bridge = bridge_mapping.split(":")[1]
-                self.ovn_bridge_mappings[network] = bridge
 
-                if not extra_routes.get(bridge):
-                    extra_routes[bridge] = (
-                        linux_net.ensure_routing_table_for_bridge(
-                            self.ovn_routing_tables, bridge,
-                            CONF.bgp_vrf_table_id))
-                vlan_tags = self.sb_idl.get_network_vlan_tag_by_network_name(
-                    network)
+        for bridge_index, bridge_mapping in enumerate(bridge_mappings, 1):
+            network, bridge = helpers.parse_bridge_mapping(bridge_mapping)
+            if not network:
+                continue
+            self.ovn_bridge_mappings[network] = bridge
 
-                for vlan_tag in vlan_tags:
-                    linux_net.ensure_vlan_device_for_network(bridge,
-                                                             vlan_tag)
+            if not extra_routes.get(bridge):
+                extra_routes[bridge] = (
+                    linux_net.ensure_routing_table_for_bridge(
+                        self.ovn_routing_tables, bridge,
+                        CONF.bgp_vrf_table_id))
+            vlan_tags = self.sb_idl.get_network_vlan_tag_by_network_name(
+                network)
 
-                linux_net.ensure_arp_ndp_enabled_for_bridge(bridge,
-                                                            bridge_index,
-                                                            vlan_tags)
+            for vlan_tag in vlan_tags:
+                linux_net.ensure_vlan_device_for_network(bridge,
+                                                         vlan_tag)
 
-                if self.ovs_flows.get(bridge):
-                    continue
-                self.ovs_flows[bridge] = {
-                    'mac': ndb.interfaces[bridge]['address'],
-                    'in_port': set([])}
-                # 3) Get in_port for bridge mappings (br-ex, br-ex2)
-                self.ovs_flows[bridge]['in_port'] = (
-                    ovs.get_ovs_patch_ports_info(bridge))
+            linux_net.ensure_arp_ndp_enabled_for_bridge(bridge,
+                                                        bridge_index,
+                                                        vlan_tags)
 
-                # 4) Add/Remove flows for each bridge mappings
-                ovs.ensure_mac_tweak_flows(bridge,
-                                           self.ovs_flows[bridge]['mac'],
-                                           self.ovs_flows[bridge]['in_port'],
-                                           constants.OVS_RULE_COOKIE)
-                ovs.remove_extra_ovs_flows(self.ovs_flows, bridge,
-                                           constants.OVS_RULE_COOKIE)
+            if self.ovs_flows.get(bridge):
+                continue
+
+            mac = linux_net.get_interface_address(bridge)
+            self.ovs_flows[bridge] = {
+                'mac': mac,
+                'in_port': set([])}
+            # 3) Get in_port for bridge mappings (br-ex, br-ex2)
+            self.ovs_flows[bridge]['in_port'] = (
+                ovs.get_ovs_patch_ports_info(bridge))
+
+            # 4) Add/Remove flows for each bridge mappings
+            ovs.ensure_mac_tweak_flows(bridge,
+                                       self.ovs_flows[bridge]['mac'],
+                                       self.ovs_flows[bridge]['in_port'],
+                                       constants.OVS_RULE_COOKIE)
+            ovs.remove_extra_ovs_flows(self.ovs_flows, bridge,
+                                       constants.OVS_RULE_COOKIE)
 
         LOG.debug("Syncing current routes.")
         exposed_ips = linux_net.get_exposed_ips(CONF.bgp_nic)
@@ -257,6 +260,9 @@ class OVNBGPDriver(driver_api.AgentDriverBase):
                                           self.ovn_routing_tables_routes,
                                           extra_routes)
 
+        wire_utils.delete_vlan_devices_leftovers(self.sb_idl,
+                                                 self.ovn_bridge_mappings)
+
     def _ensure_cr_lrp_associated_ports_exposed(self, cr_lrp_port,
                                                 exposed_ips, ovn_ip_rules):
         ips, patch_port_row = self.sb_idl.get_cr_lrp_nat_addresses_info(
@@ -322,8 +328,9 @@ class OVNBGPDriver(driver_api.AgentDriverBase):
         if not bridge_device and not bridge_vlan:
             bridge_device, bridge_vlan = self._get_bridge_for_datapath(
                 provider_datapath)
-            if not bridge_device:
-                return False
+        if (not bridge_device or
+                bridge_device not in self.ovn_bridge_mappings.values()):
+            return False
 
         localnet = self.ovn_provider_datapath.get(provider_datapath)
         if not localnet:
@@ -907,6 +914,15 @@ class OVNBGPDriver(driver_api.AgentDriverBase):
             return False
         LOG.debug("Added BGP route for CR-LRP Port %s", ips)
 
+        # Expose FIPS
+        # This is needed in case the router get disabled and enabled
+        # In that case there may be FIPs already associated to VMs
+        fips, patch_port_row = self.sb_idl.get_cr_lrp_nat_addresses_info(
+            cr_lrp_port, self.chassis, self.sb_idl)
+        fips = [ip for ip in fips if ip not in ips_without_mask]
+        if fips:
+            self._expose_ip(fips, patch_port_row, associated_port=cr_lrp_port)
+
         # Check if there are networks attached to the router,
         # and if so, add the needed routes/rules
         lrp_ports = self.sb_idl.get_lrp_ports_for_router(router_datapath)
