@@ -12,10 +12,25 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from oslo_log import log as logging
 from ovsdbapp.backend.ovs_idl import event as row_event
 
+from ovn_bgp_agent import constants
 
-class PortBindingChassisEvent(row_event.RowEvent):
+
+LOG = logging.getLogger(__name__)
+
+
+class Event(row_event.RowEvent):
+    def run(self, *args, **kwargs):
+        try:
+            self._run(*args, **kwargs)
+        except Exception:
+            LOG.exception("Unexpected exception while running the event "
+                          "action")
+
+
+class PortBindingChassisEvent(Event):
     def __init__(self, bgp_agent, events):
         self.agent = bgp_agent
         table = 'Port_Binding'
@@ -27,7 +42,7 @@ class PortBindingChassisEvent(row_event.RowEvent):
         return len(mac.strip().split(' ')) > 1
 
 
-class OVNLBMemberEvent(row_event.RowEvent):
+class OVNLBMemberEvent(Event):
     def __init__(self, bgp_agent, events):
         self.agent = bgp_agent
         table = 'Load_Balancer'
@@ -36,7 +51,7 @@ class OVNLBMemberEvent(row_event.RowEvent):
         self.event_name = self.__class__.__name__
 
 
-class LSPChassisEvent(row_event.RowEvent):
+class LSPChassisEvent(Event):
     def __init__(self, bgp_agent, events):
         self.agent = bgp_agent
         table = 'Logical_Switch_Port'
@@ -46,3 +61,14 @@ class LSPChassisEvent(row_event.RowEvent):
 
     def _check_ip_associated(self, mac):
         return len(mac.strip().split(' ')) > 1
+
+    def _get_chassis(self, row):
+        if (hasattr(row, 'external_ids') and
+                row.external_ids.get(constants.OVN_HOST_ID_EXT_ID_KEY)):
+            return (row.external_ids[constants.OVN_HOST_ID_EXT_ID_KEY],
+                    constants.OVN_CHASSIS_AT_EXT_IDS)
+        elif (hasattr(row, 'options') and
+                row.options.get(constants.OVN_REQUESTED_CHASSIS)):
+            return (row.options[constants.OVN_REQUESTED_CHASSIS],
+                    constants.OVN_CHASSIS_AT_OPTIONS)
+        return None, None
