@@ -17,7 +17,6 @@ from unittest import mock
 
 from oslo_config import cfg
 
-from ovn_bgp_agent import config
 from ovn_bgp_agent import constants
 from ovn_bgp_agent.drivers.openstack import nb_ovn_bgp_driver
 from ovn_bgp_agent.drivers.openstack.utils import bgp as bgp_utils
@@ -36,7 +35,6 @@ class TestNBOVNBGPDriver(test_base.TestCase):
 
     def setUp(self):
         super(TestNBOVNBGPDriver, self).setUp()
-        config.register_opts()
         self.bridge = 'fake-bridge'
         self.nb_bgp_driver = nb_ovn_bgp_driver.NBOVNBGPDriver()
         self.nb_bgp_driver._post_start_event = mock.Mock()
@@ -64,10 +62,6 @@ class TestNBOVNBGPDriver(test_base.TestCase):
 
         self.conf_ovsdb_connection = 'tcp:127.0.0.1:6642'
 
-        # Mock pyroute2.NDB context manager object
-        self.mock_ndb = mock.patch.object(linux_net.pyroute2, 'NDB').start()
-        self.fake_ndb = self.mock_ndb().__enter__()
-
     @mock.patch.object(linux_net, 'ensure_vrf')
     @mock.patch.object(frr, 'vrf_leak')
     @mock.patch.object(linux_net, 'ensure_ovn_device')
@@ -114,6 +108,8 @@ class TestNBOVNBGPDriver(test_base.TestCase):
         mock_ensure_ovn_dev.assert_called_once_with(
             CONF.bgp_nic, CONF.bgp_vrf)
 
+    @mock.patch.object(linux_net, 'delete_vlan_device_for_network')
+    @mock.patch.object(linux_net, 'get_bridge_vlans')
     @mock.patch.object(linux_net, 'get_extra_routing_table_for_bridge')
     @mock.patch.object(linux_net, 'delete_bridge_ip_routes')
     @mock.patch.object(linux_net, 'delete_ip_rules')
@@ -123,14 +119,16 @@ class TestNBOVNBGPDriver(test_base.TestCase):
     @mock.patch.object(ovs, 'remove_extra_ovs_flows')
     @mock.patch.object(ovs, 'ensure_mac_tweak_flows')
     @mock.patch.object(ovs, 'get_ovs_patch_ports_info')
+    @mock.patch.object(linux_net, 'get_interface_address')
     @mock.patch.object(linux_net, 'ensure_arp_ndp_enabled_for_bridge')
     @mock.patch.object(linux_net, 'ensure_vlan_device_for_network')
     @mock.patch.object(linux_net, 'ensure_routing_table_for_bridge')
     def test_sync(self, mock_routing_bridge, mock_ensure_vlan_network,
-                  mock_ensure_arp, mock_get_patch_ports, mock_ensure_mac,
-                  mock_remove_flows, mock_exposed_ips, mock_get_ip_rules,
-                  mock_del_exposed_ips, mock_del_ip_rules, mock_del_ip_routes,
-                  mock_get_extra_route):
+                  mock_ensure_arp, mock_nic_address, mock_get_patch_ports,
+                  mock_ensure_mac, mock_remove_flows, mock_exposed_ips,
+                  mock_get_ip_rules, mock_del_exposed_ips, mock_del_ip_rules,
+                  mock_del_ip_routes, mock_get_extra_route,
+                  mock_get_bridge_vlans, mock_delete_vlan_dev):
         self.mock_ovs_idl.get_ovn_bridge_mappings.return_value = [
             'net0:bridge0', 'net1:bridge1']
         self.nb_idl.get_network_vlan_tag_by_network_name.side_effect = (
@@ -151,8 +149,12 @@ class TestNBOVNBGPDriver(test_base.TestCase):
         mock_ensure_port_exposed = mock.patch.object(
             self.nb_bgp_driver, '_ensure_port_exposed').start()
         mock_routing_bridge.return_value = ['fake-route']
+        mock_nic_address.return_value = self.mac
         mock_get_patch_ports.return_value = [1, 2]
 
+        self.nb_idl.get_network_vlan_tags.return_value = [10, 11]
+        mock_get_bridge_vlans.side_effect = [[10, 12], [11]]
+
         self.nb_bgp_driver.sync()
 
         expected_calls = [mock.call({}, 'bridge0', CONF.bgp_vrf_table_id),
@@ -181,6 +183,9 @@ class TestNBOVNBGPDriver(test_base.TestCase):
         mock_del_ip_rules.assert_called_once_with(fake_ip_rules)
         mock_del_ip_routes.assert_called_once()
 
+        bridge = set(self.nb_bgp_driver.ovn_bridge_mappings.values()).pop()
+        mock_delete_vlan_dev.assert_called_once_with(bridge, 12)
+
     def test__ensure_port_exposed_fip(self):
         port0 = fakes.create_object({
             'name': 'port-0',
@@ -334,6 +339,7 @@ class TestNBOVNBGPDriver(test_base.TestCase):
         mock_get_ls_localnet_info = mock.patch.object(
             self.nb_bgp_driver, '_get_ls_localnet_info').start()
         mock_get_ls_localnet_info.return_value = ('fake-localnet', 'br-ex', 10)
+        self.nb_bgp_driver.ovn_bridge_mappings = {'fake-localnet': 'br-ex'}
 
         cidr = row.external_ids.get(constants.OVN_CIDRS_EXT_ID_KEY)
         logical_switch = row.external_ids.get(constants.OVN_LS_NAME_EXT_ID_KEY)
@@ -519,6 +525,7 @@ class TestNBOVNBGPDriver(test_base.TestCase):
             self.nb_bgp_driver, '_get_ls_localnet_info').start()
         mock_get_ls_localnet_info.return_value = ('fake-localnet', 'br-ex',
                                                   100)
+        self.nb_bgp_driver.ovn_bridge_mappings = {'fake-localnet': 'br-ex'}
         mock_expose_provider_port = mock.patch.object(
             self.nb_bgp_driver, '_expose_provider_port').start()
         row = fakes.create_object({
